HttpLogEntry class

Constructors

HttpLogEntry({required int id, required String method, required String url, required Map<String, dynamic> requestHeaders, required DateTime requestTime, dynamic requestBody, Map<String, dynamic>? queryParameters})

Properties

duration Duration?
no setter
durationLabel String
no setter
errorMessage String?
getter/setter pair
formattedRequestBody String
no setter
formattedResponseBody String
no setter
hashCode int
The hash code for this object.
no setterinherited
host String
no setter
id int
final
method String
final
path String
no setter
queryParameters Map<String, dynamic>?
final
requestBody → dynamic
final
requestHeaders Map<String, dynamic>
final
requestTime DateTime
final
responseBody ↔ dynamic
getter/setter pair
responseHeaders Map<String, String>
getter/setter pair
responseTime DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status HttpLogStatus
getter/setter pair
statusCode int?
getter/setter pair
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited