ui/http_inspector_share library

Functions

showShareSheetForAll(BuildContext context, List<HttpLogEntry> entries) → void
Shows a bottom sheet with share options for entries (e.g. the full list).
showShareSheetForEntry(BuildContext context, HttpLogEntry entry) → void
Shows a bottom sheet with share options for a single entry.