AppLogEntry class
Constructors
-
AppLogEntry({required int id, required AppLogLevel level, required String message, required DateTime time, required List<
String> lines, String? tag, Object? error, StackTrace? stackTrace})
Properties
- error → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- level → AppLogLevel
-
final
-
lines
→ List<
String> -
Pre-formatted lines as produced by the app's
LogPrinter— rendered as-is (monospace) in the log detail view.final - message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
final
- tag → String?
-
Optional tag set via
AppLog'stag:parameter — lets the Logs tab filter events by source/feature.final - time → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited