HttpNotificationService class
Manages the HTTP inspector lifecycle: local notifications + shake-to-open.
Initialized automatically by HttpInspectorInterceptor. No widget wrapper required in the app.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
init(
{bool showNotification = true}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → HttpNotificationService
-
final